@@ -1,42 +1,50 @@
-# WordNet::Similarity::vector.pm version 0.06
-# (Updated 10/10/2003 -- Sid)
+# WordNet::Similarity::vector.pm version 0.07
+# (Updated 11/13/2003 -- Jason)
 #
 # Module to accept two WordNet synsets and to return a floating point
 # number that indicates how similar those two synsets are, using a
-# gloss vector overlap measure based on "context vectors" described by 
+# gloss vector overlap measure based on "context vectors" described by
 # Schütze (1998).
-#
-# Copyright (c) 2003,
-#
-# Siddharth Patwardhan, University of Utah, Salt Lake City
-# sidd@cs.utah.edu
-#
-# Ted Pedersen, University of Minnesota, Duluth
-# tpederse@d.umn.edu
-#
-# Satanjeev Banerjee, Carnegie Mellon University, Pittsburgh
-# banerjee+@cs.cmu.edu
-#
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation; either version 2
-# of the License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to 
-#
-# The Free Software Foundation, Inc., 
-# 59 Temple Place - Suite 330, 
-# Boston, MA  02111-1307, USA.
-
 
 package WordNet::Similarity::vector;
 
+=head1 NAME
+
+WordNet::Similarity::vector - Perl module for computing semantic relatedness
+of word senses using second order co-occurrence vectors of glosses of the word
+senses.
+
+=head1 SYNOPSIS
+
+  use WordNet::Similarity::vector;
+
+  use WordNet::QueryData;
+
+  my $wn = WordNet::QueryData->new();
+
+  my $vector = WordNet::Similarity::vector->new($wn);
+
+  my $value = $vector->getRelatedness("car#n#1", "bus#n#2");
+
+  ($error, $errorString) = $vector->getError();
+
+  die "$errorString\n" if($error);
+
+  print "car (sense 1) <-> bus (sense 2) = $value\n";
+
+=head1 DESCRIPTION
+
+SchE<uuml>tze (1998) creates what he calls context vectors (second order
+co-occurrence vectors) of pieces of text for the purpose of Word Sense
+Discrimination. This idea is adopted by Patwardhan and Pedersen to represent
+the word senses by second-order co-occurrence vectors of their dictionary
+(WordNet) definitions. The relatedness of two senses is then computed as
+the cosine of their representative gloss vectors.
+
+=over
+
+=cut
+
 use strict;
 # use PDL;
 use Exporter;
@@ -53,7 +61,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
 @EXPORT = ();
 
-$VERSION = '0.06';
+$VERSION = '0.07';
 
 
 # 'new' method for the vector class... creates and returns a WordNet::Similarity::vector object.
@@ -69,11 +77,11 @@ sub new
 
     # The name of my class.
     $className = shift;
-    
+
     # Initialize the error string and the error level.
     $self->{'errorString'} = "";
     $self->{'error'} = 0;
-    
+
     # The WordNet::QueryData object.
     $wn = shift;
     $self->{'wn'} = $wn;
@@ -92,7 +100,7 @@ sub new
 }
 
 
-# Initialization of the WordNet::Similarity::vector object... parses the config file and sets up 
+# Initialization of the WordNet::Similarity::vector object... parses the config file and sets up
 # global variables, or sets them to default values.
 # INPUT PARAMS  : $paramFile .. File containing the module specific params.
 # RETURN VALUES : (none)
@@ -112,19 +120,19 @@ sub _initialize
 
     # Reference to the object.
     $self = shift;
-    
+
     # Get reference to WordNet.
     $wn = $self->{'wn'};
 
     # Name of the parameter file.
     $paramFile = shift;
-    
+
     # Initialize the $posList... Parts of Speech that this module can handle.
     $self->{"n"} = 1;
     $self->{"v"} = 1;
     $self->{"a"} = 1;
     $self->{"r"} = 1;
-    
+
     # Initialize the cache stuff.
     $self->{'doCache'} = 1;
     $self->{'simCache'} = ();
@@ -134,7 +142,7 @@ sub _initialize
     $self->{'vCache'} = ();
     $self->{'vCacheQ'} = ();
     $self->{'vCacheSize'} = 80;
-    
+
     # Initialize tracing.
     $self->{'trace'} = 0;
     $self->{'traceString'} = "";
@@ -147,7 +155,7 @@ sub _initialize
 
     # Parse the config file and
     # read parameters from the file.
-    # Looking for params --> 
+    # Looking for params -->
     # trace, infocontent file, cache
     if(defined $paramFile)
     {
@@ -210,7 +218,7 @@ sub _initialize
 		$self->{'doCache'} = 1;
 		$self->{'doCache'} = $tmp if($tmp =~ /^[01]$/);
 	    }
-	    elsif(m/^(?:max)?CacheSize::(.*)/i) 
+	    elsif(m/^(?:max)?CacheSize::(.*)/i)
 	    {
 		my $mcs = $1;
 		$self->{'maxCacheSize'} = 1000;
@@ -233,7 +241,7 @@ sub _initialize
 	}
 	close(PARAM);
     }
-    
+
     # Load the stop list.
     if($stopFile)
     {
@@ -250,7 +258,7 @@ sub _initialize
 		$stopHash{$line} = 1;
 		$self->{'stopHash'}->{$line} = 1;
 	    }
-	    close(STOP);   
+	    close(STOP);
 	}
 	else
 	{
@@ -275,7 +283,7 @@ sub _initialize
 		$line =~ s/\s+/_/g;
 		$self->{'compounds'}->{$line} = 1;		
 	    }
-	    close(COMP);   
+	    close(COMP);
 	}
 	else
 	{
@@ -288,14 +296,14 @@ sub _initialize
     # so now we are ready to initialize the get_wn_info package with
     # the wordnet object, 0/1 depending on if stemming is required and
     # the stop hash
-    if($self->{'doStem'}) 
-    { 
-	$gwi = get_wn_info->new($wn, 1, %stopHash); 
+    if($self->{'doStem'})
+    {
+	$gwi = get_wn_info->new($wn, 1, %stopHash);
 	$self->{'gwi'} = $gwi;
     }
-    else 
-    { 
-	$gwi = get_wn_info->new($wn, 0, %stopHash); 
+    else
+    {
+	$gwi = get_wn_info->new($wn, 0, %stopHash);
 	$self->{'gwi'} = $gwi;
     }
 
@@ -340,7 +348,7 @@ sub _initialize
 	$self->{'indexWord'}->[$prts[0]] = $key;
     }
     $db->finalize();
-    
+
     # Set up the interface to the word vectors...
     $db = dbInterface->new($vectorDB, "Vectors");
     if(!$db)
@@ -387,27 +395,27 @@ sub _initialize
 		while($relation = <RELATIONS>)
 		{
 		    $relation =~ s/[\r\f\n]//g;
-		    
+	
 		    # now for each line in the <REL> file, extract the
 		    # nested functions if any, check if they are defined,
 		    # if it makes sense to nest them, and then finally put
 		    # them into the @functions triple dimensioned array!
-		    
+	
 		    # remove leading/trailing spaces from the relation
 		    $relation =~ s/^\s+//;
 		    $relation =~ s/\s+$//;
-		    
+	
 		    # now extract the weight if any. if no weight, assume 1
 		    if($relation =~ /(\S+)\s+(\S+)/)
 		    {
 			$relation = $1;
 			$self->{'weights'}->[$index] = $2;
 		    }
-		    else 
-		    { 
-			$self->{'weights'}->[$index] = 1; 
+		    else
+		    {
+			$self->{'weights'}->[$index] = 1;
 		    }
-		    
+	
 # 		    # check if we have a "proper" relation, that is a relation in
 # 		    # there are two blocks of functions!
 # # 		    if($relation !~ /(.*)-(.*)/)
@@ -418,13 +426,13 @@ sub _initialize
 # # 			close(RELATIONS);
 # # 			return;		
 # # 		    }
-		    
+	
 # 		    # get the two parts of the relation pair
 # 		    my @twoParts;
 # 		    my $l;
 # 		    $twoParts[0] = $1;
 # 		    $twoParts[1] = $2;
-		    
+	
 		    # process the relation and put into functions array
 #		    for($l = 0; $l < 2; $l++)
 		    {
@@ -445,8 +453,8 @@ sub _initialize
 			}
 			
 			$self->{'functions'}->[$index]->[$j++] = $functionArray[$#functionArray];
-			my $input; 
-			my $output; 
+			my $input;
+			my $output;
 			my $dummy;
 			my $k;
 			
@@ -462,10 +470,10 @@ sub _initialize
 				close(RELATIONS);
 				return;
 			    }
-			    
+	
 			    ($input, $dummy) = $gwi->$fn2(0);
 			    ($dummy, $output) = $gwi->$fn3(0);
-			    
+	
 			    if($input != $output)
 			    {
 				$self->{'errorString'} .= "\nError (WordNet::Similarity::vector->_initialize()) - ";
@@ -474,7 +482,7 @@ sub _initialize
 				close(RELATIONS);
 				return;
 			    }
-			    
+	
 			    $self->{'functions'}->[$index]->[$j++] = $functionArray[$k];
 			}
 			
@@ -482,12 +490,12 @@ sub _initialize
 			# wrap a glos around it
 			my $xfn = $functionArray[0];
 			($dummy, $output) = $gwi->$xfn(0);
-			if($output == 1) 
-			{ 
-			    $self->{'functions'}->[$index]->[$j++] = "glos"; 
+			if($output == 1)
+			{
+			    $self->{'functions'}->[$index]->[$j++] = "glos";
 			}
 		    }
-		    
+	
 		    $index++;
 		}
 	    }
@@ -499,7 +507,7 @@ sub _initialize
 		close(RELATIONS);
 		return;		
 	    }
-	    close(RELATIONS);   
+	    close(RELATIONS);
 	}
 	else
 	{
@@ -509,7 +517,7 @@ sub _initialize
 	    return;
 	}
     }
-    
+
     # [trace]
     $self->{'traceString'} = "WordNet::Similarity::vector object created:\n";
     $self->{'traceString'} .= "trace          :: ".($self->{'trace'})."\n" if(defined $self->{'trace'});
@@ -525,12 +533,20 @@ sub _initialize
 }
 
 
-# The gloss vector relatedness measure subroutine ...
-# INPUT PARAMS  : $wps1     .. one of the two wordsenses.
-#                 $wps2     .. the second wordsense of the two whose 
-#                              semantic relatedness needs to be measured.
-# RETURN VALUES : $distance .. the semantic relatedness of the two word senses.
-#              or undef     .. in case of an error.
+=item $vector->getRelatedness ($synset1, $synset2)
+
+Computes the relatedness of two word senses using the vector measure
+developed by Patwardhan.
+
+Parameters: two word senses in "word#pos#sense" format.
+
+Returns: Unless a problem occurs, the return value is the relatedness
+score, which is greater-than or equal-to 0.  If an error occurs,
+then the error level is set to non-zero and an error string
+is created (see the description of getError()).
+
+=cut
+
 sub getRelatedness
 {
     my $self = shift;
@@ -589,7 +605,7 @@ sub getRelatedness
     {
 	if($self->{'trace'})
 	{
-	    # ah so we do need SOME traces! put in the synset names. 
+	    # ah so we do need SOME traces! put in the synset names.
 	    $self->{'traceString'} .= "Synset 1: $wps1 (Gloss Vector found in Cache)\n";
 	    $self->{'traceString'} .= "Synset 2: $wps2 (Gloss Vector found in Cache)\n";
 	}	
@@ -599,7 +615,7 @@ sub getRelatedness
 #	my $score = $cos->sclr();
 
 	# that does all the scoring. Put in cache if doing cacheing. Then
-	# return the score.    
+	# return the score.
 	if($self->{'doCache'})
 	{
 	    $self->{'simCache'}->{"${wps1}::$wps2"} = $score;
@@ -622,18 +638,18 @@ sub getRelatedness
     # second synset in another "set" of itself. These sets may
     # increase in size as the functions are applied (since some
     # relations have a one to many mapping).
-    
+
     # initialize the first set with the first synset
-    my @firstSet = (); 
+    my @firstSet = ();
     push @firstSet, $wps1;
-    
+
     # initialize the second set with the second synset
     my @secondSet = ();
     push @secondSet, $wps2;
-    
+
     # initialize the score
     my $score = 0;
-    
+
     # and now go thru the functions array, get the strings and do the scoring
     my $i = 0;
     my %overlaps;
@@ -714,7 +730,7 @@ sub getRelatedness
     $secondString =~ s/^\s+//;
     $secondString =~ s/\s+$//;
     $secondString = $self->_compoundify($secondString);
-    
+
     # Get vectors... score...
     my $a;
     my $maga;
@@ -724,10 +740,10 @@ sub getRelatedness
     my $sizeb;
     my $trr;
 
-    # see if any traces reqd. if so, put in the synset arrays. 
+    # see if any traces reqd. if so, put in the synset arrays.
     if($self->{'trace'})
     {
-	# ah so we do need SOME traces! put in the synset names. 
+	# ah so we do need SOME traces! put in the synset names.
 	$self->{'traceString'} .= "Synset 1: $wps1";
     }
     if(defined $self->{'vCache'}->{$wps1})
@@ -751,7 +767,7 @@ sub getRelatedness
 
     if($self->{'trace'})
     {
-	# ah so we do need SOME traces! put in the synset names. 
+	# ah so we do need SOME traces! put in the synset names.
 	$self->{'traceString'} .= "Synset 2: $wps2";
     }
     if(defined $self->{'vCache'}->{$wps2})
@@ -775,9 +791,9 @@ sub getRelatedness
 
     $score = &_inner($a, $b);
 #    $score = $cos->sclr();
-   
+
     # that does all the scoring. Put in cache if doing cacheing. Then
-    # return the score.    
+    # return the score.
     if($self->{'doCache'})
     {
 	$self->{'simCache'}->{"${wps1}::$wps2"} = $score;
@@ -793,7 +809,7 @@ sub getRelatedness
 	    }
 	}
     }
-    
+
     return $score;
 }
 
@@ -875,7 +891,7 @@ sub _getVector
     {
 	$mag += ($ret->{$kk} * $ret->{$kk});
     }
-    
+
     return ($ret, $localTraces, sqrt($mag));
 }
 
@@ -939,20 +955,20 @@ sub _compoundify
     my $firstPointer;
     my $secondPointer;
     my @wordsArray;
-    
+
     return undef if(!defined $block);
-    
+
     # get all the words into an array
     @wordsArray = ();
     while ($block =~ /(\w+)/g)
     {
 	push @wordsArray, $1;
     }
-    
+
     # now compoundify, GREEDILY!!
     $firstPointer = 0;
     $string = "";
-    
+
     while($firstPointer <= $#wordsArray)
     {
 	$secondPointer = $#wordsArray;
@@ -962,17 +978,17 @@ sub _compoundify
 	    $temp = join ("_", @wordsArray[$firstPointer..$secondPointer]);
 	    if(exists $self->{'compounds'}->{$temp})
 	    {
-		$string .= "$temp "; 
+		$string .= "$temp ";
 		$done = 1;
 	    }
-	    else 
-	    { 
-		$secondPointer--; 
+	    else
+	    {
+		$secondPointer--;
 	    }
 	}
-	if(!$done) 
-	{ 
-	    $string .= "$wordsArray[$firstPointer] "; 
+	if(!$done)
+	{
+	    $string .= "$wordsArray[$firstPointer] ";
 	}
 	$firstPointer = $secondPointer + 1;
     }
@@ -985,54 +1001,24 @@ sub _compoundify
 
 __END__
 
-=head1 NAME
+=back
 
-WordNet::Similarity::vector - Perl module for computing semantic relatedness
-of word senses using second order co-occurrence vectors of glosses of the word
-senses.
-
-=head1 SYNOPSIS
-
-  use WordNet::Similarity::vector;
-
-  use WordNet::QueryData;
-
-  my $wn = WordNet::QueryData->new();
-
-  my $vector = WordNet::Similarity::vector->new($wn);
-
-  my $value = $vector->getRelatedness("car#n#1", "bus#n#2");
-
-  ($error, $errorString) = $vector->getError();
-
-  die "$errorString\n" if($error);
-
-  print "car (sense 1) <-> bus (sense 2) = $value\n";
-
-=head1 DESCRIPTION
-
-Schütze (1998) creates what he calls context vectors (second order 
-co-occurrence vectors) of pieces of text for the purpose of Word Sense
-Discrimination. This idea is adopted by Patwardhan and Pedersen to represent the 
-word senses by second-order co-occurrence vectors of their dictionary (WordNet) 
-definitions. The relatedness of two senses is then computed as the cosine of 
-their representative gloss vectors.
-
-=head1 USAGE
+=head2 Usage
 
 The semantic relatedness modules in this distribution are built as classes
-that expose the following methods:
-  new()
-  getRelatedness()
-  getError()
-  getTraceString()
+that define the following methods:
+
+    new()
+    getRelatedness()
+    getError()
+    getTraceString()
 
 See the WordNet::Similarity(3) documentation for details of these methods.
 
-=head1 TYPICAL USAGE EXAMPLES
+=head3 Typical Usage Examples
 
 To create an object of the vector measure, we would have the following
-lines of code in the Perl program. 
+lines of code in the Perl program.
 
   use WordNet::Similarity::vector;
   $measure = WordNet::Similarity::vector->new($wn, '/home/sid/vector.conf');
@@ -1041,7 +1027,7 @@ The reference of the initialized object is stored in the scalar variable
 '$measure'. '$wn' contains a WordNet::QueryData object that should have been
 created earlier in the program. The second parameter to the 'new' method is
 the path of the configuration file for the vector measure. If the 'new'
-method is unable to create the object, '$measure' would be undefined. This, 
+method is unable to create the object, '$measure' would be undefined. This,
 as well as any other error/warning may be tested.
 
   die "Unable to create object.\n" if(!defined $measure);
@@ -1053,7 +1039,7 @@ the second sense of the noun 'bus' using the measure, we would write
 the following piece of code:
 
   $relatedness = $measure->getRelatedness('car#n#1', 'bus#n#2');
-  
+
 To get traces for the above computation:
 
   print $measure->getTraceString();
@@ -1069,98 +1055,142 @@ parameters are initialized within the object. A configuration file may be
 specified as a parameter during the creation of an object using the new
 method. The configuration files must follow a fixed format.
 
-Every configuration file starts with the name of the module ON THE FIRST LINE of
-the file. For example, a configuration file for the vector module will have
-on the first line 'WordNet::Similarity::vector'. This is followed by the various
-parameters, each on a new line and having the form 'name::value'. The
+Every configuration file starts with the name of the module ON THE FIRST LINE
+of the file. For example, a configuration file for the vector module will have
+on the first line 'WordNet::Similarity::vector'. This is followed by the
+various parameters, each on a new line and having the form 'name::value'. The
 'value' of a parameter is optional (in case of boolean parameters). In case
 'value' is omitted, we would have just 'name::' on that line. Comments are
 supported in the configuration file. Anything following a '#' is ignored till
 the end of the line.
 
-The module parses the configuration file and recognizes the following 
+The module parses the configuration file and recognizes the following
 parameters:
 
-(a) 'trace::' -- The value of this parameter specifies the level of
-tracing that should be employed for generating the traces. This value
-is an integer 0, 1 or 2. A value of 0 switches tracing off. A value of
-1 displays as traces only the gloss overlaps found. A value of 2 displays
-as traces, all the text being compared.
+=over
 
-(b) 'relation::' -- The value is a filename (with complete path) of a file
-that contains a list of WordNet-relations. The vector module combines the
-glosses of synsets related to the target synsets by these relations, and 
-forms the gloss-vector from this combined gloss. The format of the relation
-file is specified later in the documentation.
+=item trace
 
-(c) 'vectordb::' -- Value is a Berkeley DB database file containing word 
-vectors, i.e. co-occurrence vectors for all the words in the WordNet 
-glosses.
+The value of this parameter specifies the level of tracing that should
+be employed for generating the traces. This value
+is an integer equal to 0, 1, or 2. If the value is omitted, then the
+default value, 0, is used. A value of 0 switches tracing off. A value
+of 1 or 2 switches tracing on.  A value of 1 displays as
+traces only the gloss overlaps found. A value of 2 displays as traces all
+the text being compared.
 
-(d) 'stop::' -- The value is a string that specifies the path of a file 
-containing a list of stop words that should be ignored in the gloss 
-vectors.
+=item cache
 
-(e) 'compounds::' -- The value is a string that specifies the path of a file 
-containing a list of compound words in WordNet.
+The value of this parameter specifies whether or not caching of the
+relatedness values should be performed.  This value is an
+integer equal to  0 or 1.  If the value is omitted, then the default
+value, 1, is used. A value of 0 switches caching 'off', and
+a value of 1 switches caching 'on'.
 
-(f) 'stem::' -- can take values 0 or 1 or the value can be omitted, in 
-which case it takes the value 1, i.e. switches 'on' stemming. A value of 
-0 switches stemming 'off'. When stemming is enabled, all the words of the
-glosses are stemmed before their vectors are created.
+=item maxCacheSize
 
-(g) 'cache::' -- can take values 0 or 1 or the value can be omitted, in 
-which case it takes the value 1, i.e. switches 'on' caching. A value of 
-0 switches caching 'off'. By default caching is enabled.
+The value of this parameter indicates the size of the cache, used for
+storing the computed relatedness value. The specified value must be
+a non-negative integer.  If the value is omitted, then the default
+value, 5,000, is used. Setting maxCacheSize to zero has
+the same effect as setting cache to zero, but setting cache to zero is
+likely to be more efficient.  Caching and tracing at the same time can result
+in excessive memory usage because the trace strings are also cached.  If
+you intend to perform a large number of relatedness queries, then you
+might want to turn tracing off.
 
-(h) 'maxCacheSize::' -- takes a non-negative integer value. The value indicates
-the size of the cache, used for storing the computed relatedness value.
+=item relation
+
+The value of this parameter is the path to a file that contains a list of
+WordNet relations.  The path may be either an absolute path or a relative
+path.
+
+The vector module combines the glosses of synsets related to the target
+synsets by these relations and forms the gloss-vector from this combined
+gloss.
+
+WARNING: the format of the relation file is different for the vector and lesk
+measures.
+
+=item stop
+
+The value of this parameter the path of a file containing a list of stop
+words that should be ignored in the glosses.  The path may be either an
+absolute path or a relative path.
+
+=item stem
+
+The value of this parameter indicates whether or not stemming should be
+performed.  The value must be an integer equal to 0 or 1.  If the
+value is omitted, then the default value, 0, is used.
+A value of 1 switches 'on' stemming, and a value of 0 switches stemming
+'off'. When stemming is enabled, all the words of the
+glosses are stemmed before their vectors are created for the vector
+measure or their overlaps are compared for the lesk measure.
+
+=item compounds
+
+The value of this parameter is the path of a file containing a list of
+compound words in WordNet.  This path may be either an absolute path or
+a relative path.  If the value is omitted, then the default
+behavior (no compound recognition) is used.
+
+=item vectordb
+
+The value of this parameter is the path to a Berkeley DB file
+containing word vectors, i.e. co-occurrence vectors for all the words
+in the WordNet glosses.  The value of this parameter may not be omitted,
+and the vector measure will not run without a DB file being specified
+in a configuration file.
+
+=back
 
 =head1 RELATION FILE FORMAT
 
 The relation file starts with the string "VectorRelationFile" on the first line
 of the file. Following this, on each consecutive line, a relation is specified
-in the form -- 
+in the form --
 
-func(func(func... (func)...)) [weight]
+ func(func(func... (func)...)) [weight]
 
 Where "func" can be any one of the following functions:
 
-hype() = Hypernym of
-hypo() = Hyponym of
-holo() = Holonym of
-mero() = Meronym of
-attr() = Attribute of
-also() = Also see
-sim() = Similar
-enta() = Entails
-caus() = Causes
-part() = Particle
-pert() = Pertainym of
-glos = gloss (without example)
-example = example (from the gloss)
-glosexample = gloss + example
-syns = the synset of the concept
+ hype() = Hypernym of
+ hypo() = Hyponym of
+ holo() = Holonym of
+ mero() = Meronym of
+ attr() = Attribute of
+ also() = Also see
+ sim() = Similar
+ enta() = Entails
+ caus() = Causes
+ part() = Particle
+ pert() = Pertainym of
+ glos = gloss (without example)
+ example = example (from the gloss)
+ glosexample = gloss + example
+ syns = the synset of the concept
 
 Each of these specifies a WordNet relation. And the outermost function in the
-nesting can only be one of glos, example, glosexample or syns. The functions specify which 
-glosses to use for forming the gloss vector of the synset. An optional weight can be 
+nesting can only be one of glos, example, glosexample or syns. The functions specify which
+glosses to use for forming the gloss vector of the synset. An optional weight can be
 specified to weigh the contribution of that relation in the overall score.
 
 For example,
 
-glos(hype(hypo)) 0.5
+ glos(hype(hypo)) 0.5
 
-means that the gloss of the hypernym of the hyponym of the synset is used to form the 
-gloss vector of the synset, and the values in this vector are weighted by 0.5. If one of "glos", 
-"example", "glosexample" or "syns" is not specified as the outermost function in the nesting, 
+means that the gloss of the hypernym of the hyponym of the synset is used to
+form the gloss vector of the synset, and the values in this vector are
+weighted by 0.5. If one of "glos", "example", "glosexample" or "syns" is not
+specified as the outermost function in the nesting,
 then "glosexample" is assumed by default. This implies that
 
-glosexample(hypo(also))
+ glosexample(hypo(also))
 
 and
 
-hypo(also)
+ hypo(also)
 
 are equivalent as far as the measure is concerned.
 
@@ -1178,15 +1208,44 @@ http://groups.yahoo.com/group/wn-similarity
 
 =head1 AUTHORS
 
-  Siddharth Patwardhan, <sidd@cs.utah.edu>
-  Ted Pedersen, <tpederse@d.umn.edu>
-  Satanjeev Banerjee, <banerjee+@cs.cmu.edu>
+ Siddharth Patwardhan, University of Utah, Salt Lake City
+ sidd at cs.utah.edu
+
+ Ted Pedersen, University of Minnesota, Duluth
+ tpederse at d.umn.edu
+
+ Satanjeev Banerjee, Carnegie Mellon University, Pittsburgh
+ banerjee+ at cs.cmu.edu
+
+=head1 BUGS
+
+To report bugs, go to http://groups.yahoo.com/group/wn-similarity/ or
+send an e-mail to "S<tpederse at d.umn.edu>".
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003 by Siddharth Patwardhan, Ted Pedersen and Satanjeev Banerjee
+Copyright (C) 2003-2004, Siddharth Patwardhan, Ted Pedersen and Satanjeev
+Banerjee
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. 
+This program is free software; you can redistribute it and/or
+modify it under the terms of the GNU General Public License
+as published by the Free Software Foundation; either version 2
+of the License, or (at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to
+
+    The Free Software Foundation, Inc.,
+    59 Temple Place - Suite 330,
+    Boston, MA  02111-1307, USA.
+
+Note: a copy of the GNU General Public License is available on the web
+at L<http://www.gnu.org/licenses/gpl.txt> and is included in this
+distribution as GPL.txt.
 
 =cut
